#!/bin/sh
#----------------------------------------------------------------------------
# /tmp/preinstall.sh - cups preinstallation
#
# Creation   :  2022-05-18 holbru
# Last update:  $Id: preinstall.sh 107751 2023-11-23 13:18:23Z hbfl $
#
# Copyright (c) 2022-2024 Holger Bruenjes, holgerbruenjes(at)gmx(dot)net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# set package name
package_name=cups

. /var/install/include/eislib

# ---------------------------------------------------------------------------
# check for lprng package
# ---------------------------------------------------------------------------
installed=$(eisman check lprng)

if [ "${installed}" = "installed" ]
then
    echo
    mecho --warn -n 'It is not possible to install '
    mecho --std  -n "'CUPS' "
    mecho --warn -n 'or '
    mecho --std  -n "'CUPS-client' "
    mecho --warn -n 'and '
    mecho --std  -n "'LPRng' "
    mecho --warn    'at the same time,'
    mecho --warn -n 'it is necessary to uninstall on command line '
    mecho --std  -n "'LPRng' "
    mecho --warn    'first.'
    mecho --warn -n 'Backup your existing'
    mecho --std  -n "'LPRng' " 
    mecho --warn     'configuration file to a safe place, f.e.:'
    echo
    mecho --error   'cp /etc/config.d/lprng /root/lprng'
    echo
    mecho --info    'Deinstall LPRng:'
    echo
    mecho --error   'eisman uninstall --force lprng'
    echo
    mecho --info -n 'Please note: '
    mecho --std  -n "'LPRng' "
    mecho --info -n 'will be replaced by '
    mecho --std  -n "'CUPS'"
    mecho --info    '.'
    echo
    anykey

    exit 1
fi

exit 0
# ---------------------------------------------------------------------------
# end
# ---------------------------------------------------------------------------
